@@ -1,3 +1,4 @@
+import json
 import rows
 from django.core.management.base import BaseCommand
 
@@ -14,7 +15,7 @@ class Command(BaseCommand):
         writer = rows.utils.CsvLazyDictWriter(options["output_filename"])
         for element in ElementConfig.objects.all().iterator():
             writer.writerow({
-                key: value
+                key: value if key != "data" else json.dumps(value)
                 for key, value in element.__dict__.items()
                 if key != "_state"
             })
