@@ -495,6 +495,10 @@ class DatasetModel(models.Model):
         db_index=True,
     )
 
+    @classmethod
+    def extra(cls, qs):
+        return {}
+
     @classmethod
     def fields(cls):
         from django.db import connection
