@@ -235,7 +235,10 @@ class DatasetFilter(APIView):
 
     def get(self, request, slug, object_uuid):
         Model = self.get_model(slug)
-        objects = Model.objects.filter(object_uuid=object_uuid)
+        if hasattr(Model.objects, "for_object"):
+            objects = Model.objects.for_object(object_uuid=object_uuid)
+        else:
+            objects = Model.objects.filter(object_uuid=object_uuid)
         data = {
             "fields": Model.fields(),
             "result": [obj.serialize() for obj in objects],
